package org.kantega.jexmec.simple;

/*
 * Copyright 2010 Kantega AS
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import org.kantega.jexmec.Plugin;
import org.kantega.jexmec.PluginClassLoaderRegistry;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

/**
 */
public class JarFilePluginClassLoaderProvider extends StaticPluginClassLoaderProvider {
    private File workDirectory;
    private Class<? extends Plugin> pluginClass;
    private ClassLoader parentClassLoader;
    private List<File>  filesAdded = new ArrayList<File>();

    public JarFilePluginClassLoaderProvider(Class<? extends Plugin> pluginClass, ClassLoader parentClassLoader, File workDirectory) {
        this.pluginClass = pluginClass;
        this.parentClassLoader = parentClassLoader;
        this.workDirectory = workDirectory;
    }

    public void addJarsInDirectory(File directory) {

        if(!directory.isDirectory()) {
            return;
        }

        for(File file : directory.listFiles()) {
            if(file.isFile() && file.getName().toLowerCase().endsWith(".jar")) {
               addClassLoader(new JarFilePluginClassLoader(pluginClass,  file, parentClassLoader, workDirectory));
                filesAdded.add(file);
            }
        }
    }

    @Override
    public void start(PluginClassLoaderRegistry registry) {
        super.start(registry);
        for(File file : workDirectory.listFiles()) {
            if(!filesAdded.contains(file)) {
                deleteFile(file);

            }
        }
    }

    private void deleteFile(File file) {
        if(file.isDirectory()) {
            for(File child : file.listFiles()) {
                deleteFile(child);
            }
        }
        file.delete();
    }
}
