package org.kantega.jexmec.simple;

/*
 * Copyright 2010 Kantega AS
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import org.kantega.jexmec.PluginClassLoaderProvider;
import org.kantega.jexmec.PluginClassLoaderRegistry;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * PluginLoader using a static list of classloaders.
 */
public class StaticPluginClassLoaderProvider implements PluginClassLoaderProvider {
    private List<ClassLoader> classLoaders = new ArrayList<ClassLoader>();
    private PluginClassLoaderRegistry registry;

    public StaticPluginClassLoaderProvider(List<ClassLoader> classLoaders) {
        this.classLoaders.addAll(classLoaders);
    }

    public StaticPluginClassLoaderProvider(ClassLoader... classLoaders) {
        this.classLoaders.addAll(Arrays.asList(classLoaders));
    }

    public void addClassLoader(ClassLoader... classLoaders) {
        this.classLoaders.addAll(Arrays.asList(classLoaders));
    }

    public void start(PluginClassLoaderRegistry registry) {
        this.registry = registry;
        for (ClassLoader loader : classLoaders) {
            registry.addClassLoader(loader);
        }
    }

    public void stop() {
        for (ClassLoader loader : classLoaders) {
            registry.removeClassLoader(loader);
        }
    }

    public List<ClassLoader> getClassLoaders() {
        return classLoaders;
    }
}
