package org.kantega.jexmec.simple;

/*
 * Copyright 2010 Kantega AS
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import org.kantega.jexmec.ServiceKey;
import org.kantega.jexmec.ServiceLocator;

import java.util.Set;
import java.util.Collections;
import java.util.Map;
import java.util.HashMap;

/**
 * Service locator for
 */
public class StaticServiceLocator implements ServiceLocator {

    private final Map<ServiceKey, Object> services;

    public StaticServiceLocator() {
        this(Collections.<ServiceKey, Object>emptyMap());
    }

    public StaticServiceLocator(Map<ServiceKey, Object> services) {
        this.services = new HashMap<ServiceKey, Object>(services);
    }

    public Set<ServiceKey> getServiceKeys() {
        return services.keySet();
    }

    public <T> T lookupService(ServiceKey<T> serviceKey) {
        return serviceKey.getServiceType().cast(services.get(serviceKey));
    }

    public <T> void addService(ServiceKey serviceKey,  T serviceImplementation) {
        this.services.put(serviceKey, serviceImplementation);
    }
}
